# Copyright (c) 2011 Cloudera, Inc. All rights reserved.

from cmf.monitor.json_metrics_utils import get_leaf_dict

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self._json = json_dict
    self.master = get_leaf_dict(self._json, 'hbase', 'master')
    self.jvm = get_leaf_dict(self._json, 'jvm', 'metrics')

#
# This is what the master json looks like:
#
SAMPLE = """
{
   "hbase":{
      "info":[

      ],
      "master":[
         [
            {
               "Master":"localhost:60000",
               "hostName":"bigrig"
            },
            {
               "cluster_requests":0.0,
               "splitSize_avg_time":59,
               "splitSize_num_ops":5,
               "splitTime_avg_time":616,
               "splitTime_num_ops":5
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"bigrig",
               "processName":"Master",
               "sessionId":"localhost:60000"
            },
            {
               "gcCount":3,
               "gcTimeMillis":15,
               "logError":0,
               "logFatal":0,
               "logInfo":0,
               "logWarn":0,
               "maxMemoryM":910.25,
               "memHeapCommittedM":118.875,
               "memHeapUsedM":30.40583,
               "memNonHeapCommittedM":23.1875,
               "memNonHeapUsedM":19.257584,
               "threadsBlocked":1,
               "threadsNew":2,
               "threadsRunnable":3,
               "threadsTerminated":4,
               "threadsTimedWaiting":5,
               "threadsWaiting":6
            }
         ]
      ]
   },
   "rpc":{
      "metrics":[
         [
            {
               "hostName":"bigrig",
               "port":"60000"
            },
            {
               "RpcProcessingTime_avg_time":0,
               "RpcProcessingTime_num_ops":0,
               "RpcQueueTime_avg_time":0,
               "RpcQueueTime_num_ops":0,
               "addColumn_avg_time":0,
               "addColumn_num_ops":0,
               "assign_avg_time":0,
               "assign_num_ops":0,
               "balanceSwitch_avg_time":0,
               "balanceSwitch_num_ops":0,
               "balance_avg_time":0,
               "balance_num_ops":0,
               "bulkLoadHFile_avg_time":0,
               "bulkLoadHFile_num_ops":0,
               "checkAndDelete_avg_time":0,
               "checkAndDelete_num_ops":0,
               "checkAndPut_avg_time":0,
               "checkAndPut_num_ops":0,
               "closeRegion_avg_time":0,
               "closeRegion_num_ops":0,
               "close_avg_time":0,
               "close_num_ops":0,
               "compactRegion_avg_time":0,
               "compactRegion_num_ops":0,
               "createTable_avg_time":0,
               "createTable_num_ops":0,
               "deleteColumn_avg_time":0,
               "deleteColumn_num_ops":0,
               "deleteTable_avg_time":0,
               "deleteTable_num_ops":0,
               "delete_avg_time":0,
               "delete_num_ops":0,
               "disableTable_avg_time":0,
               "disableTable_num_ops":0,
               "enableTable_avg_time":0,
               "enableTable_num_ops":0,
               "exists_avg_time":0,
               "exists_num_ops":0,
               "flushRegion_avg_time":0,
               "flushRegion_num_ops":0,
               "getClosestRowBefore_avg_time":0,
               "getClosestRowBefore_num_ops":0,
               "getClusterStatus_avg_time":0,
               "getClusterStatus_num_ops":0,
               "getHServerInfo_avg_time":0,
               "getHServerInfo_num_ops":0,
               "getOnlineRegions_avg_time":0,
               "getOnlineRegions_num_ops":0,
               "getProtocolVersion_avg_time":0,
               "getProtocolVersion_num_ops":8,
               "getRegionInfo_avg_time":0,
               "getRegionInfo_num_ops":0,
               "get_avg_time":0,
               "get_num_ops":0,
               "incrementColumnValue_avg_time":0,
               "incrementColumnValue_num_ops":0,
               "increment_avg_time":0,
               "increment_num_ops":0,
               "isMasterRunning_avg_time":0,
               "isMasterRunning_num_ops":3,
               "lockRow_avg_time":0,
               "lockRow_num_ops":0,
               "modifyColumn_avg_time":0,
               "modifyColumn_num_ops":0,
               "modifyTable_avg_time":0,
               "modifyTable_num_ops":0,
               "move_avg_time":0,
               "move_num_ops":0,
               "multiPut_avg_time":0,
               "multiPut_num_ops":0,
               "multi_avg_time":0,
               "multi_num_ops":0,
               "next_avg_time":0,
               "next_num_ops":0,
               "openRegion_avg_time":0,
               "openRegion_num_ops":0,
               "openRegions_avg_time":0,
               "openRegions_num_ops":0,
               "openScanner_avg_time":0,
               "openScanner_num_ops":0,
               "put_avg_time":0,
               "put_num_ops":0,
               "regionServerReport_avg_time":0,
               "regionServerReport_num_ops":776,
               "regionServerStartup_avg_time":0,
               "regionServerStartup_num_ops":5,
               "replicateLogEntries_avg_time":0,
               "replicateLogEntries_num_ops":0,
               "shutdown_avg_time":0,
               "shutdown_num_ops":0,
               "splitRegion_avg_time":0,
               "splitRegion_num_ops":0,
               "stopMaster_avg_time":0,
               "stopMaster_num_ops":0,
               "unassign_avg_time":0,
               "unassign_num_ops":0,
               "unlockRow_avg_time":0,
               "unlockRow_num_ops":0
            }
         ]
      ]
   },
   "ugi":{
      "ugi":[
         [
            {
               "hostName":"bigrig"
            },
            {
               "loginFailure_avg_time":0,
               "loginFailure_num_ops":0,
               "loginSuccess_avg_time":0,
               "loginSuccess_num_ops":0
            }
         ]
      ]
   }
}
"""
