# Copyright (c) 2011 Cloudera, Inc. All rights reserved.

from cmf.monitor.json_metrics_utils import get_leaf_dict

class JsonParser(object):
  def __init__(self, json_dict):
    """
    May raise ParseError if the json structure is not what
    we expect.
    """
    self._json = json_dict
    self.regionserver = get_leaf_dict(self._json, 'hbase', 'regionserver')
    self.jvm = get_leaf_dict(self._json, 'jvm', 'metrics')
    self.rpc = get_leaf_dict(self._json, 'rpc', 'metrics')

#
# This is what the regionserver json looks like:
#
SAMPLE = """
{
   "hbase":{
      "info":[

      ],
      "regionserver":[
         [
            {
               "RegionServer":"regionserver60020",
               "hostName":"bigrig"
            },
            {
               "blockCacheCount":2,
               "blockCacheEvictedCount":0,
               "blockCacheFree":189325112,
               "blockCacheHitCachingRatio":92,
               "blockCacheHitCount":26,
               "blockCacheHitRatio":92,
               "blockCacheMissCount":2,
               "blockCacheSize":1568152,
               "compactionQueueSize":3,
               "compactionSize_avg_time":0,
               "compactionSize_num_ops":0,
               "compactionTime_avg_time":0,
               "compactionTime_num_ops":0,
               "flushQueueSize":1,
               "flushSize_avg_time":0,
               "flushSize_num_ops":0,
               "flushTime_avg_time":0,
               "flushTime_num_ops":0,
               "fsReadLatency_avg_time":0,
               "fsReadLatency_num_ops":2,
               "fsSyncLatency_avg_time":0,
               "fsSyncLatency_num_ops":13437,
               "fsWriteLatency_avg_time":0,
               "fsWriteLatency_num_ops":2,
               "memstoreSizeMB":10,
               "regions":2,
               "requests":0,
               "storefileIndexSizeMB":0,
               "storefiles":2,
               "stores":3
            }
         ]
      ]
   },
   "jvm":{
      "metrics":[
         [
            {
               "hostName":"bigrig",
               "processName":"RegionServer",
               "sessionId":"regionserver60020"
            },
            {
               "gcCount":53,
               "gcTimeMillis":117,
               "logError":0,
               "logFatal":0,
               "logInfo":0,
               "logWarn":0,
               "maxMemoryM":910.25,
               "memHeapCommittedM":95.875,
               "memHeapUsedM":25.67759,
               "memNonHeapCommittedM":23.1875,
               "memNonHeapUsedM":20.116676,
               "threadsBlocked":1,
               "threadsNew":2,
               "threadsRunnable":3,
               "threadsTerminated":4,
               "threadsTimedWaiting":5,
               "threadsWaiting":6
            }
         ]
      ]
   },
   "rpc":{
      "metrics":[
         [
            {
               "hostName":"bigrig",
               "port":"60020"
            },
            {
               "RpcProcessingTime_avg_time":0,
               "RpcProcessingTime_num_ops":0,
               "RpcQueueTime_avg_time":0,
               "RpcQueueTime_num_ops":0,
               "abort_avg_time":0,
               "abort_num_ops":0,
               "addColumn_avg_time":0,
               "addColumn_num_ops":0,
               "addToOnlineRegions_avg_time":0,
               "addToOnlineRegions_num_ops":0,
               "assign_avg_time":0,
               "assign_num_ops":0,
               "balanceSwitch_avg_time":0,
               "balanceSwitch_num_ops":0,
               "balance_avg_time":0,
               "balance_num_ops":0,
               "bulkLoadHFile_avg_time":0,
               "bulkLoadHFile_num_ops":0,
               "checkAndDelete_avg_time":0,
               "checkAndDelete_num_ops":0,
               "checkAndPut_avg_time":7,
               "checkAndPut_num_ops":49,
               "checkOOME_avg_time":0,
               "checkOOME_num_ops":0,
               "closeRegion_avg_time":0,
               "closeRegion_num_ops":0,
               "close_avg_time":0,
               "close_num_ops":53,
               "compactRegion_avg_time":0,
               "compactRegion_num_ops":0,
               "createTable_avg_time":0,
               "createTable_num_ops":0,
               "deleteColumn_avg_time":0,
               "deleteColumn_num_ops":0,
               "deleteTable_avg_time":0,
               "deleteTable_num_ops":0,
               "delete_avg_time":0,
               "delete_num_ops":0,
               "disableTable_avg_time":0,
               "disableTable_num_ops":0,
               "enableTable_avg_time":0,
               "enableTable_num_ops":0,
               "exists_avg_time":0,
               "exists_num_ops":0,
               "flushRegion_avg_time":0,
               "flushRegion_num_ops":0,
               "getClosestRowBefore_avg_time":0,
               "getClosestRowBefore_num_ops":4,
               "getClusterStatus_avg_time":0,
               "getClusterStatus_num_ops":0,
               "getFromOnlineRegions_avg_time":0,
               "getFromOnlineRegions_num_ops":0,
               "getHServerInfo_avg_time":0,
               "getHServerInfo_num_ops":0,
               "getOnlineRegions_avg_time":0,
               "getOnlineRegions_num_ops":0,
               "getProtocolVersion_avg_time":0,
               "getProtocolVersion_num_ops":5,
               "getRegionInfo_avg_time":0,
               "getRegionInfo_num_ops":53,
               "get_avg_time":1,
               "get_num_ops":3,
               "incrementColumnValue_avg_time":0,
               "incrementColumnValue_num_ops":0,
               "increment_avg_time":0,
               "increment_num_ops":0,
               "isMasterRunning_avg_time":0,
               "isMasterRunning_num_ops":0,
               "isStopped_avg_time":0,
               "isStopped_num_ops":0,
               "lockRow_avg_time":0,
               "lockRow_num_ops":0,
               "modifyColumn_avg_time":0,
               "modifyColumn_num_ops":0,
               "modifyTable_avg_time":0,
               "modifyTable_num_ops":0,
               "move_avg_time":0,
               "move_num_ops":0,
               "multiPut_avg_time":0,
               "multiPut_num_ops":0,
               "multi_avg_time":2,
               "multi_num_ops":20,
               "next_avg_time":0,
               "next_num_ops":53,
               "openRegion_avg_time":0,
               "openRegion_num_ops":2,
               "openRegions_avg_time":0,
               "openRegions_num_ops":0,
               "openScanner_avg_time":0,
               "openScanner_num_ops":53,
               "put_avg_time":0,
               "put_num_ops":1,
               "regionServerReport_avg_time":0,
               "regionServerReport_num_ops":0,
               "regionServerStartup_avg_time":0,
               "regionServerStartup_num_ops":0,
               "removeFromOnlineRegions_avg_time":0,
               "removeFromOnlineRegions_num_ops":0,
               "replicateLogEntries_avg_time":0,
               "replicateLogEntries_num_ops":0,
               "shutdown_avg_time":0,
               "shutdown_num_ops":0,
               "splitRegion_avg_time":0,
               "splitRegion_num_ops":0,
               "stopMaster_avg_time":0,
               "stopMaster_num_ops":0,
               "stop_avg_time":0,
               "stop_num_ops":0,
               "unassign_avg_time":0,
               "unassign_num_ops":0,
               "unlockRow_avg_time":0,
               "unlockRow_num_ops":0
            }
         ]
      ]
   },
   "ugi":{
      "ugi":[
         [
            {
               "hostName":"bigrig"
            },
            {
               "loginFailure_avg_time":0,
               "loginFailure_num_ops":0,
               "loginSuccess_avg_time":0,
               "loginSuccess_num_ops":0
            }
         ]
      ]
   }
}
"""
